Documentation
¶
Overview ¶
Package postgres provides a Gnomock Preset for PostgreSQL database
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Preset ¶
Preset creates a new Gmomock Postgres preset. This preset includes a Postgres specific healthcheck function, default Postgres image and port, and allows to optionally set up initial state
Example ¶
package main
import (
"database/sql"
"fmt"
"github.com/orlangure/gnomock"
mockpostgres "github.com/orlangure/gnomock-postgres"
)
func main() {
queries := `
create table t(a int);
insert into t (a) values (1);
insert into t (a) values (2);
`
query := `insert into t (a) values (3);`
p := mockpostgres.Preset(
mockpostgres.WithUser("gnomock", "gnomick"),
mockpostgres.WithDatabase("mydb"),
mockpostgres.WithQueries(queries, query),
)
container, err := gnomock.Start(p)
if err != nil {
panic(err)
}
defer func() { _ = gnomock.Stop(container) }()
connStr := fmt.Sprintf(
"host=%s port=%d user=%s password=%s dbname=%s sslmode=disable",
container.Host, container.DefaultPort(),
"gnomock", "gnomick", "mydb",
)
db, err := sql.Open("postgres", connStr)
if err != nil {
panic(err)
}
var max, avg, min, count float64
rows := db.QueryRow("select max(a), avg(a), min(a), count(a) from t")
err = rows.Scan(&max, &avg, &min, &count)
if err != nil {
panic("can't query the database: " + err.Error())
}
fmt.Println("max", 3)
fmt.Println("avg", 2)
fmt.Println("min", 1)
fmt.Println("count", 3)
}
Output: max 3 avg 2 min 1 count 3
Types ¶
type Option ¶
type Option func(*options)
Option is an optional configuration of this Gnomock preset. Use available Options to configure the container
func WithDatabase ¶
WithDatabase creates a database with the provided name in the container. WithQueries, if provided, runs against the new database
func WithQueries ¶
WithQueries executes the provided queries against the database created with WithDatabase, or against default postgres database
Click to show internal directories.
Click to hide internal directories.